@@ -7,16 +7,17 @@ import org.gnu.gtk.event.MouseListener;
 
 /**
  * MouseListener delegate class.
- *
+ * 
  * @author Tom Ball
  */
 class MouseDelegate extends ListenerDelegate implements MouseListener {
 
-	public MouseDelegate(String signal, Object owner, Method handler, Object target) throws NoSuchMethodException {
-		super(signal, owner, handler, target);
-	}
+    public MouseDelegate(String signal, Object owner, Method handler,
+            Object target) throws NoSuchMethodException {
+        super(signal, owner, handler, target);
+    }
 
-	public boolean mouseEvent(MouseEvent event) {
-		return fireEvent(event);
-	}
+    public boolean mouseEvent(MouseEvent event) {
+        return fireEvent(event);
+    }
 }
