@@ -7,16 +7,17 @@ import org.gnu.gtk.event.ToggleListener;
 
 /**
  * ToggleListener delegate class.
- *
+ * 
  * @author Tom Ball
  */
 class ToggleDelegate extends ListenerDelegate implements ToggleListener {
 
-	public ToggleDelegate(String signal, Object owner, Method handler, Object target) throws NoSuchMethodException {
-		super(signal, owner, handler, target);
-	}
+    public ToggleDelegate(String signal, Object owner, Method handler,
+            Object target) throws NoSuchMethodException {
+        super(signal, owner, handler, target);
+    }
 
-	public void toggleEvent(ToggleEvent event) {
-		fireEvent(event);
-	}
+    public void toggleEvent(ToggleEvent event) {
+        fireEvent(event);
+    }
 }
